@@ -110,7 +110,8 @@ class BigQueryTableUsageExtractor(BaseBigQueryExtractor):
             tableId = self._remove_table_decorators(tableId)
 
             if self._is_sharded_table(tableId):
-                tableId = tableId[:-BigQueryTableUsageExtractor.DATE_LENGTH]
+                # Use the prefix of the sharded table as tableId
+                tableId = tableId[:-len(self._get_sharded_table_suffix(tableId))]
 
             # GCP console allows running queries using tables from a project different from the one the extractor is
             # used for; only usage metadata of referenced tables present in the given project_id_key for the
